@@ -22,6 +22,10 @@
 # Boston, MA 02110-1301 USA,
 
 import unittest
+# fix for MacOS using nose
+import collections
+collections.Callable = collections.abc.Callable
+
 from pprint import pprint
 
 
